==> haskell-hsopenssl-0.11.7.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsopenssl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HsOpenSSL
version:              0.11.7.2
visibility:           public
id:                   HsOpenSSL-0.11.7.2-FyM8wenGX9VANUpRXwUDZP
key:                  HsOpenSSL-0.11.7.2-FyM8wenGX9VANUpRXwUDZP
license:              LicenseRef-PublicDomain
maintainer:           Vladimir Shabanov <dev@vshabanov.com>
author:               Adam Langley, Mikhail Vorozhtsov, PHO, Taru Karttunen
stability:            stable
homepage:             https://github.com/vshabanov/HsOpenSSL
synopsis:             Partial OpenSSL binding for Haskell
description:
    HsOpenSSL is an OpenSSL binding for Haskell. It can generate RSA
    and DSA keys, read and write PEM files, generate message digests,
    sign and verify messages, encrypt and decrypt messages. It has
    also some capabilities of creating SSL clients and servers.

    This package is in production use by a number of Haskell based
    systems and stable. You may also be interested in the @tls@ package,
    <http://hackage.haskell.org/package/tls>, which is a pure Haskell
    implementation of SSL.

category:             Cryptography
abi:                  bea99f1311f01c58a7f909f297c93cc4
exposed:              True
exposed-modules:
    OpenSSL OpenSSL.BN OpenSSL.Cipher OpenSSL.DER OpenSSL.DH
    OpenSSL.DSA OpenSSL.EVP.Base64 OpenSSL.EVP.Cipher
    OpenSSL.EVP.Digest OpenSSL.EVP.Internal OpenSSL.EVP.Open
    OpenSSL.EVP.PKey OpenSSL.EVP.Seal OpenSSL.EVP.Sign
    OpenSSL.EVP.Verify OpenSSL.PEM OpenSSL.PKCS7 OpenSSL.RSA
    OpenSSL.Random OpenSSL.Session OpenSSL.X509 OpenSSL.X509.Request
    OpenSSL.X509.Revocation OpenSSL.X509.Store

hidden-modules:
    OpenSSL.ASN1 OpenSSL.BIO OpenSSL.ERR OpenSSL.Objects
    OpenSSL.SSL.Option OpenSSL.Stack OpenSSL.Utils OpenSSL.X509.Name
    OpenSSL.DH.Internal

import-dirs:          /usr/lib/ghc-9.0.1/site-local/HsOpenSSL-0.11.7.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/HsOpenSSL-0.11.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/HsOpenSSL-0.11.7.2
hs-libraries:         HSHsOpenSSL-0.11.7.2-FyM8wenGX9VANUpRXwUDZP
extra-libraries:      ssl crypto
includes:             openssl/asn1.h
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    network-3.1.2.2-AIHAQTgcOP2p9DGqwUMBL time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-hsopenssl/html/HsOpenSSL.haddock
haddock-html:         /usr/share/doc/haskell-hsopenssl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsopenssl-0.11.7.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsopenssl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HsOpenSSL
version:              0.11.7.2
visibility:           public
id:                   HsOpenSSL-0.11.7.2-LEvYoS0AreU6BZoVfDGBXW
key:                  HsOpenSSL-0.11.7.2-LEvYoS0AreU6BZoVfDGBXW
license:              LicenseRef-PublicDomain
maintainer:           Vladimir Shabanov <dev@vshabanov.com>
author:               Adam Langley, Mikhail Vorozhtsov, PHO, Taru Karttunen
stability:            stable
homepage:             https://github.com/vshabanov/HsOpenSSL
synopsis:             Partial OpenSSL binding for Haskell
description:
    HsOpenSSL is an OpenSSL binding for Haskell. It can generate RSA
    and DSA keys, read and write PEM files, generate message digests,
    sign and verify messages, encrypt and decrypt messages. It has
    also some capabilities of creating SSL clients and servers.

    This package is in production use by a number of Haskell based
    systems and stable. You may also be interested in the @tls@ package,
    <http://hackage.haskell.org/package/tls>, which is a pure Haskell
    implementation of SSL.

category:             Cryptography
abi:                  d35ee5970adca7533cfba1c904e8f912
exposed:              True
exposed-modules:
    OpenSSL OpenSSL.BN OpenSSL.Cipher OpenSSL.DER OpenSSL.DH
    OpenSSL.DSA OpenSSL.EVP.Base64 OpenSSL.EVP.Cipher
    OpenSSL.EVP.Digest OpenSSL.EVP.Internal OpenSSL.EVP.Open
    OpenSSL.EVP.PKey OpenSSL.EVP.Seal OpenSSL.EVP.Sign
    OpenSSL.EVP.Verify OpenSSL.PEM OpenSSL.PKCS7 OpenSSL.RSA
    OpenSSL.Random OpenSSL.Session OpenSSL.X509 OpenSSL.X509.Request
    OpenSSL.X509.Revocation OpenSSL.X509.Store

hidden-modules:
    OpenSSL.ASN1 OpenSSL.BIO OpenSSL.ERR OpenSSL.Objects
    OpenSSL.SSL.Option OpenSSL.Stack OpenSSL.Utils OpenSSL.X509.Name
    OpenSSL.DH.Internal

import-dirs:          /usr/lib/ghc-9.0.1/site-local/HsOpenSSL-0.11.7.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/HsOpenSSL-0.11.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/HsOpenSSL-0.11.7.2
hs-libraries:         HSHsOpenSSL-0.11.7.2-LEvYoS0AreU6BZoVfDGBXW
extra-libraries:      ssl crypto
includes:             openssl/asn1.h
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    network-3.1.2.2-6tZsGK4OV907qcZzBxrezj time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-hsopenssl/html/HsOpenSSL.haddock
haddock-html:         /usr/share/doc/haskell-hsopenssl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
